@@ -66,12 +66,6 @@ const gchar *crash_type[] = {
 	NULL
 };
 
-const gchar *bug_type[] = {
-	N_("Create a new bug report"),
-	N_("Add more information to existing report"),
-	NULL
-};
-
 PoptData popt_data;
 
 DruidData druid_data;
@@ -435,7 +429,7 @@ init_gnome_version_stuff (void)
 	xmlDoc *doc;
 	char *xml_file;
 	xmlNode *node;
-	char *platform, *minor, *micro, *vendor;
+	char *platform, *minor, *micro, *distributor;
 
 
 	druid_data.gnome_version = g_getenv ("BUG_BUDDY_GNOME_VERSION");
@@ -449,7 +443,7 @@ init_gnome_version_stuff (void)
 	if (!doc)
 		return;
 
-	platform = minor = micro = vendor = NULL;
+	platform = minor = micro = distributor = NULL;
 	
 	for (node = xmlDocGetRootElement (doc)->children; node; node = node->next) {
 		if (!strcmp (node->name, "platform"))
@@ -458,20 +452,20 @@ init_gnome_version_stuff (void)
 			minor = xmlNodeGetContent (node);
 		else if (!strcmp (node->name, "micro"))
 			micro = xmlNodeGetContent (node);
-		else if (!strcmp (node->name, "vendor"))
-			vendor = xmlNodeGetContent (node);
+		else if (!strcmp (node->name, "distributor"))
+			distributor = xmlNodeGetContent (node);
 	}
 	
 	if (platform && minor && micro)
 		druid_data.gnome_platform_version = g_strdup_printf ("GNOME%s.%s.%s", platform, minor, micro);
   
-	if (vendor && *vendor)
-		druid_data.gnome_vendor = g_strdup (vendor);
+	if (distributor && *distributor)
+		druid_data.gnome_distributor = g_strdup (distributor);
 	
 	xmlFree (platform);
 	xmlFree (minor);
 	xmlFree (micro);
-	xmlFree (vendor);
+	xmlFree (distributor);
 	
 	xmlFreeDoc (doc);
 }
@@ -516,36 +510,19 @@ init_ui (void)
 	}
 	if (s) {
 		buddy_set_text ("gdb-pid-entry", s);
+		druid_data.bug_type = BUG_CRASH;
 		druid_data.crash_type = CRASH_DIALOG;
+		druid_set_state (STATE_GDB);
 	}
 
 	/* core crash page */
 	if (popt_data.core_file) {
 		buddy_set_text ("gdb-core-entry", popt_data.core_file);
 		druid_data.crash_type = CRASH_CORE;
+		druid_data.bug_type = BUG_DEBUG;
+		druid_set_state (STATE_GDB);
 	}
 
-	{
-		char *message = g_strconcat (_("Welcome to Bug Buddy, a bug reporting tool for GNOME.\n"
-					       "It will step you through the process of submitting a bug report."),
-					     druid_data.crash_type == CRASH_DIALOG
-					     ? _("\n\nYou are seeing this because another application has crashed.")
-					     : "",
-					     druid_data.crash_type != CRASH_NONE
-					     ? _("\n\nPlease wait a few moments while Bug Buddy obtains debugging information "
-						 "from the applications.  This allows Bug Buddy to provide a more useful "
-						 "bug report.")
-					     : "",
-					     NULL);
-		g_object_set (GET_WIDGET ("gdb-label"),
-			      "label", message,
-			      "selectable", TRUE,
-			      NULL);
-		g_free (message);
-	}
-
-	if (druid_data.crash_type != CRASH_NONE) 
-
 	/* package version */
 	buddy_set_text ("the-version-entry", popt_data.package_ver);
 
@@ -726,7 +703,7 @@ main (int argc, char *argv[])
 	}
 	g_free (s);	
 
-	druid_set_state (STATE_GDB);
+	druid_set_state (STATE_INTRO);
 
 	init_gnome_version_stuff ();
 	init_ui ();
